<?php

namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use SM\Traits\TQuery;

class Sm00024000ModeloDocumentoFactory
{

    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getInformacoesModeloDocumento()
    {
        $sql = "SELECT NRSEQMODDOCFCT,
                        DSMODELODOCORCA,
                        IDATIVO,
                        IDDOCRENEGOCIACAO,
                        VRTAMANHOLOGO,
                        NRORG
                    FROM FCT_MODELODOC
                    ORDER BY NRSEQMODDOCFCT DESC";
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getTabAnexo($params)
    {
        $sql = "SELECT MO.NRMODELODOCIDIOMA,
                       MO.NRSEQMODDOCFCT, 
                       MO.CDIDIOM,
                       DECODE(IDI.IDPADRAO, 'S', MD.NMARQUIVO, MO.NMARQUIVO) AS NMARQUIVO,
                       DECODE(IDI.IDPADRAO, 'S', MD.DSCAMINHOARQ, MO.DSCAMINHOARQ) AS DSCAMINHOARQ,
                       DECODE(IDI.IDPADRAO, 'S', MD.DSTIPO, MO.DSTIPO) AS DSTIPO,
                       DECODE(IDI.IDPADRAO, 'S', MD.VRTAMANHO, MO.VRTAMANHO) AS VRTAMANHO,
                       MO.IDATIVO,            
                       IDI.NMIDIOMA,
                       IDI.IDPADRAO,
                       MO.NRORG
                  FROM FCT_MODELODOCIDIOMA MO
                 INNER JOIN IDIOMA IDI
                    ON MO.CDIDIOM = IDI.CDIDIOM
                 INNER JOIN FCT_MODELODOC MD
                    ON MO.NRSEQMODDOCFCT = MD.NRSEQMODDOCFCT
                 WHERE MO.NRSEQMODDOCFCT = :NRSEQMODDOCFCT
                 UNION ALL
                SELECT NULL AS NRMODELODOCIDIOMA,
                       MD.NRSEQMODDOCFCT,
                       IDIOMA.CDIDIOM,
                       MD.NMARQUIVO,
                       MD.DSCAMINHOARQ,
                       MD.DSTIPO,
                       MD.VRTAMANHO,
                       MD.IDATIVO,
                       IDIOMA.NMIDIOMA,
                       IDIOMA.IDPADRAO,
                       MD.NRORG
                  FROM FCT_MODELODOC MD
                  JOIN IDIOMA
                    ON IDIOMA.IDPADRAO = 'S'
                 WHERE NOT EXISTS (SELECT 1
                                     FROM FCT_MODELODOCIDIOMA
                                     JOIN IDIOMA
                                       ON FCT_MODELODOCIDIOMA.CDIDIOM = IDIOMA.CDIDIOM
                                    WHERE NRSEQMODDOCFCT = MD.NRSEQMODDOCFCT
                                      AND IDIOMA.IDPADRAO = 'S')
                    AND NRSEQMODDOCFCT = :NRSEQMODDOCFCT
                    AND MD.NMARQUIVO IS NOT NULL";
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function inserirModeloDocumento($parametros)
    {
        $sql = "INSERT INTO FCT_MODELODOC (NRSEQMODDOCFCT, DSMODELODOCORCA, IDATIVO, IDDOCRENEGOCIACAO, VRTAMANHOLOGO, NRORG, NRORGINCLUSAO, CDOPERINCLUSAO, DTINCLUSAO)
        VALUES (:NRSEQMODDOCFCT, :DSMODELODOCORCA, :IDATIVO, :IDDOCRENEGOCIACAO, :VRTAMANHOLOGO, :NRORG, :NRORGINCLUSAO, :CDOPERINCLUSAO, SYSDATE)";
        $this->connection->executeStatement($sql, $parametros);
    }

    public function saveTabModeloDocumento($parametros)
    {
        $sql = "UPDATE FCT_MODELODOC
                SET DSMODELODOCORCA       = :DSMODELODOCORCA,
                        IDATIVO           = :IDATIVO,
                        IDDOCRENEGOCIACAO = :IDDOCRENEGOCIACAO,
                        VRTAMANHOLOGO     = :VRTAMANHOLOGO,
                        NRORGULTATU       = :NRORGULTATU,
                        CDOPERULTATU      = :CDOPERULTATU,
                        DTULTATU          = SYSDATE
                WHERE NRSEQMODDOCFCT = :NRSEQMODDOCFCT";
        $this->connection->executeStatement($sql, $parametros);
    }

    public function validaDocIdioma($params)
    {

        $sql = "SELECT COUNT (*) AS QTD 
                FROM FCT_MODELODOCIDIOMA
                WHERE NRSEQMODDOCFCT  = :NRSEQMODDOCFCT
                AND CDIDIOM           = :CDIDIOM
                AND NRMODELODOCIDIOMA <> NVL(:NRMODELODOCIDIOMA, -1)";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function validaDoc($params)
    {

        $sql = "SELECT COUNT (*) AS QTD 
                    FROM FCT_MODELODOC
                    WHERE NRSEQMODDOCFCT  = :NRSEQMODDOCFCT
                    AND NMARQUIVO   = :NMARQUIVO
                    AND NMARQUIVO <> NVL(:NMARQUIVO, -1)";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function inserirModeloDocumentoIdioma($parametros)
    {
        $sql = "INSERT INTO FCT_MODELODOCIDIOMA (
                    NRMODELODOCIDIOMA,      NRSEQMODDOCFCT,         CDIDIOM,
                    IDATIVO,                NMARQUIVO,              DSCAMINHOARQ,           
                    DSTIPO,                 VRTAMANHO,              NRORG,                  
                    NRORGINCLUSAO,          CDOPERINCLUSAO,         DTINCLUSAO           
                    )
                    VALUES(
                    :NRMODELODOCIDIOMA,     :NRSEQMODDOCFCT,        :CDIDIOM,
                    :IDATIVO,               :NMARQUIVO,             :DSCAMINHOARQ,          
                    :DSTIPO,                :VRTAMANHO,             :NRORG,                 
                    :NRORGINCLUSAO,         :CDOPERINCLUSAO,        SYSDATE
                    )";
        $this->connection->executeStatement($sql, $parametros);
    }

    public function atualizarModeloDocumentoIdioma($parametros)
    {
        $sql = "UPDATE FCT_MODELODOCIDIOMA
                SET NRSEQMODDOCFCT = :NRSEQMODDOCFCT,
                        CDIDIOM     = :CDIDIOM,
                        IDATIVO = :IDATIVO,
                        NMARQUIVO = :NMARQUIVO,
                        DSCAMINHOARQ = :DSCAMINHOARQ,
                        DSTIPO = :DSTIPO,
                        VRTAMANHO = :VRTAMANHO,
                        CDOPERULTATU = :CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU,
                        DTULTATU = SYSDATE
                WHERE NRMODELODOCIDIOMA = :NRMODELODOCIDIOMA";
        $this->connection->executeStatement($sql, $parametros);
    }

    public function atualizarModeloDocumento($parametros)
    {
        $sql = "UPDATE FCT_MODELODOC
                SET     NMARQUIVO = :NMARQUIVO,
                        DSCAMINHOARQ = :DSCAMINHOARQ,
                        DSTIPO = :DSTIPO,
                        VRTAMANHO = :VRTAMANHO,
                        CDOPERULTATU = :CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU,
                        DTULTATU = SYSDATE
                WHERE NRSEQMODDOCFCT = :NRSEQMODDOCFCT";
        $this->connection->executeStatement($sql, $parametros);
    }

    public function limparAnexoTabModeloDoc(array $parametros)
    {
        $sql = "UPDATE FCT_MODELODOC
                   SET NMARQUIVO = NULL,
                       DSCAMINHOARQ = NULL,
                       DSTIPO = NULL,
                       VRTAMANHO = NULL
                 WHERE NRSEQMODDOCFCT = :NRSEQMODDOCFCT";
        $this->connection->executeStatement($sql, $parametros);
    }

    public function deletarAnexo($params)
    {
        $sql = "DELETE FROM FCT_MODELODOCIDIOMA
                WHERE NRMODELODOCIDIOMA = :NRMODELODOCIDIOMA";
        $this->connection->executeStatement($sql, $params);
    }

    public function deletarModeloDocumento($parametro)
    {
        $sql = "DELETE FROM FCT_MODELODOC
                WHERE NRSEQMODDOCFCT = :NRSEQMODDOCFCT";
        $this->connection->executeStatement($sql, $parametro);
    }


    public function limparAnexoModeloDocumento(array $params)
    {
        $sql = "UPDATE FCT_MODELODOCIDIOMA
                   SET DSCAMINHOARQ = NULL,
                       NMARQUIVO    = NULL,
                       VRTAMANHO    = NULL,
                       DSTIPO       = NULL
                 WHERE NRMODELODOCIDIOMA = :NRMODELODOCIDIOMA";
        $this->connection->executeStatement($sql, $params);
    }


    public function getDocumento(array $params)
    {
        $sql = "SELECT NMARQUIVO,
                  VRTAMANHO,
                  DSCAMINHOARQ,
                  DSTIPO
                FROM FCT_MODELODOCIDIOMA
                WHERE NRMODELODOCIDIOMA = :NRMODELODOCIDIOMA";
        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function getDocumentoAnt(array $params)
    {
        $sql = "SELECT NMARQUIVO,
                  VRTAMANHO,
                  DSCAMINHOARQ,
                  DSTIPO
                FROM FCT_MODELODOC
                WHERE NRSEQMODDOCFCT = :NRSEQMODDOCFCT";
        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }
}
