<?php

namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use SM\Traits\TQuery;

class Sm00052001DescontoMaximoServicoOperadorFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getNomeOperadorDescontoMaximoServicoOperador()
    {

        $sql = "SELECT DISTINCT OP.NMOPERADOR, QT.NRPARCNEGOCIO
                    FROM FCT_PERCDESCOPER QT
                    INNER JOIN OPERADOR OP 
                    ON QT.NRPARCNEGOCIO = OP.NRPARCNEGOCIO
                    WHERE QT.IDTIPO = 'D'";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getServicoDescontoMaximoServicoOperador(array $params)
    {

        $sql = "SELECT QT.NRSEQDESC, QT.VRPERCDESC,SR.NMSERVORCA,SR.CDSERVORCA, QT.NRPARCNEGOCIO
                    FROM FCT_PERCDESCOPER QT
                    INNER JOIN FCT_SERVICOORCA SR
                    ON SR.CDSERVORCA = QT.CDSERVORCA
                    WHERE QT.IDTIPO = 'D' 
                    AND NRPARCNEGOCIO = :NRPARCNEGOCIO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function validaDados(array $params)
    {

        $sql = "SELECT COUNT(*) AS VALIDA 
                    FROM FCT_PERCDESCOPER 
                    WHERE IDTIPO = 'D' 
                    AND NRPARCNEGOCIO = :NRPARCNEGOCIO
                    AND CDSERVORCA = :CDSERVORCA
                    AND NRSEQDESC <> :NRSEQDESC";


        $retorno = $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
        return $retorno[0]['VALIDA'];
    }

    public function insertDescMaxServicoOperador(array $params)
    {

        $sql = "INSERT INTO FCT_PERCDESCOPER (
                    NRSEQDESC,       NRPARCNEGOCIO,   CDSERVORCA,
                    VRPERCDESC,      NRORG,           IDATIVO,         
                    DTINCLUSAO,      NRORGINCLUSAO,   CDOPERINCLUSAO,
                    IDTIPO
                )
                VALUES (
                    :NRSEQDESC,      :NRPARCNEGOCIO,   :CDSERVORCA,
                    :VRPERCDESC,     :NRORG,           :IDATIVO,       
                    SYSDATE,         :NRORG,           :CDOPERINCLUSAO,
                    'D'
                )";

        $this->connection->executeStatement($sql, $params);
    }

    public function updateDescMaxServicoOperador($params)
    {
        $sql = "UPDATE FCT_PERCDESCOPER 
                    SET NRPARCNEGOCIO   = :NRPARCNEGOCIO, 
                    CDSERVORCA          = :CDSERVORCA,
                    VRPERCDESC          = :VRPERCDESC,
                    NRORG               = :NRORG, 
                    IDATIVO             = :IDATIVO,
                    NRORGULTATU         = :NRORG,
                    CDOPERULTATU        = :CDOPERULTATU,
                    DTULTATU            = SYSDATE
                    WHERE NRSEQDESC     = :NRSEQDESC";
        $this->connection->executeStatement($sql, $params);
    }

    public function deleteDescMaxServicoModalServico($params)
    {
        $sql = "DELETE FROM FCT_PERCDESCOPER
                WHERE NRSEQDESC = :NRSEQDESC";

        $this->connection->executeStatement($sql, $params);
    }
}
